Welcome to pygama's documentation!
==================================

`pygama <https://github.com/legend-exp/pygama>`_ is a Python package for:

* converting physics data acquisition system output to LEGEND LH5-format HDF5 files
* performing bulk digital signal processing on time-series data
* optimizing those digital signal processing (DSP) routines and tuning associated analysis parameters
* generating and selecting high-level event data for further analysis

Table of Contents
-----------------

.. toctree::
   :maxdepth: 1

   install
   manuals/index
   tutorials
   Package API reference <generated/modules>
   developer
